Crate imagequant [−] [src]
Converts RGBA images to 8-bit with alpha channel.
This is based on imagequant library, which generates very high quality images.
See examples/ directory for example code.
Reexports
pub use ffi::liq_error::*; |
Structs
| Attributes |
Settings for the conversion proces. Start here. |
| Histogram |
Generate one shared palette for multiple images. |
| Image |
Describes image dimensions for the library. |
| QuantizationResult |
Palette inside. |
Enums
| liq_error |
Functions
| new |
Type Definitions
| Color |
8-bit RGBA. This is the only color format used by the library. |
| HistogramEntry |